import pymysql


class DBMySQL:
    def __init__(self, sql_conn_str):
        '''
        127.0.0.1,3306,newdb,sa,123456,
        '''
        print('''conn DBMySQL database''')
        sqlstr = sql_conn_str.split(',')
        self.conn = pymysql.connect(host=sqlstr[0],
                                    port=int(sqlstr[1]),
                                    user=sqlstr[3],
                                    passwd=sqlstr[4],
                                    db=sqlstr[2],
                                    charset='utf8')
        self.dowork = False
        self.cursor = self.conn.cursor()

    # 开启事务
    def setDoWork(self):
        print('DBMySQL.setDoWork')
        self.dowork = True

    def commitWork(self):
        print('DBMySQL.commitWork')
        self.conn.commit()

    def backWork(self):
        print('DBMySQL.backWork')
        self.conn.rollback()

    def __del__(self):
        self.close()

    def exec(self, sql_str, sql_par=()):
        print(sql_str)
        print(sql_par)
        try:
            self.cursor.execute(sql_str, sql_par)
            if self.dowork is False:
                print('exec.commit')
                self.conn.commit()

            # 返回影响数
            return self.cursor.rowcount
        except Exception as e:
            if self.dowork is False:
                self.conn.rollback()
            print('DBMySQL.exec:', e)
            raise e

    def query_all(self, sql_str, sql_par=()):
        cur = self.query(sql_str=sql_str, sql_par=sql_par)
        que = cur.fetchall()
        cols = cur.description
        tmp = []
        for v in que:
            row = {}
            for v2 in range(0, len(cols)):
                row[cols[v2][0]] = v[v2]
            tmp.append(row)
        return tmp

    def query_one(self, sql_str, sql_par=()):
        cur = self.query(sql_str=sql_str, sql_par=sql_par)
        que = cur.fetchone()
        if que is None:
            return None
        cols = cur.description
        row = {}
        for v2 in range(0, len(cols)):
            row[cols[v2][0]] = que[v2]
        return row

    def query(self, sql_str, sql_par=()):
        print(sql_str)
        print(sql_par)
        # 执行SQL语句
        self.cursor.execute(sql_str, sql_par)
        return self.cursor

    def getcols(self):
        return self.cursor.description

    def get_db(self):
        if self.cursor is None:
            self.cursor = self.conn.cursor()
        return self.cursor

    def close(self):
        if self.conn is not None:
            self.conn.close()
        print('''close DBMySQL database''')

    def add(self, obj, tableName):
            sql = "INSERT INTO `"+ tableName +"` "
            par = []
            bval = '('
            eval = '('
            for key in obj:
                bval = bval + str(key) + ','
                eval = eval + '%s,'
                par.append(obj[key])

            bval = bval[0:-1] + ')'
            eval = eval[0:-1] + ') '
            sql = sql + bval + ' VALUES ' + eval
            bak = self.exec(sql_str=sql, sql_par=par)
            return bak

    def delById(self, id,tableName):
        if id <= 0:
            raise Exception("id < 0")
        sql = 'DELETE FROM `' + tableName + '` WHERE id = %s'
        par = [id]

        bak = self.exec(sql_str=sql, sql_par=par)
        return bak

    def findById(self, id,tableName):
        if id <= 0:
            raise Exception("id < 0")
        sql = 'SELECT * FROM `' + tableName + '` where id = %s'
        par = [id]

        bak = self.query(sql_str=sql, sql_par=par).fetchone()
        return bak


import redis


class RedisPoolTools:
    selfpool=None

    @staticmethod
    def initPools(host='127.0.0.1',port=6379,password=None):
        RedisPoolTools.selfpool = redis.ConnectionPool(host=host, port=port,password=password, decode_responses=True)

    def __init__(self):
        self.rd = redis.Redis(connection_pool=RedisPoolTools.selfpool)
        pass

    def StringSet(self,key,val,ex=None):
        self.rd.set(key, val,ex=ex)
    
    def StringGet(self,key):
        return self.rd.get(key)

    def HasSet(self,haskey,key,val,ex=None):
        self.rd.hset(haskey,key,val,ex)

    def HasGet(self,haskey,key):
        return self.rd.hget(haskey,key)

    # def timeout(self):
    #     self.rd.t

    def HasAll(self,name):
        return self.rd.hgetall(name)


import redis

class RedisTools:
    def __init__(self,host='localhost',port=6379,db=0,pwd=None):
        self.rd = redis.StrictRedis(host=host, port=6379, db=0,password=pwd)

    def StringSet(self,key,val,ex=None):
        self.rd.set(key, val,ex=ex)
    
    def StringGet(self,key):
        return self.rd.get(key)

    def HasSet(self,haskey,key,val,ex=None):
        self.rd.hset(haskey,key,val,ex)

    def HasGet(self,haskey,key,val):
        return self.rd.hget(haskey,key)

    # def timeout(self):
    #     self.rd.t

    def HasAll(self,name):
        return self.rd.hgetall(name)



import requests
import datetime


class DingDingPush:

    @staticmethod
    def pushMsg(dingdingpushURLS:str,content:str,isAtAll=True) -> str:
        inow = datetime.datetime.now()
        jsonReq = {
            "msgtype": "text", 
            "text": {
                "content": f'[{inow}]::{content}'
            }, 
            "at": {
                # "atMobiles": [
                #     "156xxxx8827", 
                #     "189xxxx8325"
                # ], 
                "isAtAll": isAtAll
            }
        }

        bak = requests.post(dingdingpushURLS,json=jsonReq )
        return bak

    def __init__(self,pushurl:str, titles:str ):
        self.msgs = ''
        self.pushurl = pushurl
        self.title = titles

    def addmd(self,msg):
        self.msgs = self.msgs + msg + '\n'

    def pushmd(self) -> (str, str):

        jsonReq = {
            "msgtype": "markdown",
            "markdown": {
                "title": self.title,
                "text": self.msgs
            },
            "at": {
                # "atMobiles": [
                #     "17707640806"
                # ], 
                "isAtAll": True
            }
        }

        tmpmsgs = self.msgs
        bak = requests.post(self.pushurl,json=jsonReq )
        self.msgs = ''
        return bak, tmpmsgs



import hashlib


class StringTools:
    def __init__(self):
        pass

    @staticmethod
    def getMd5(data:str) -> str:
        return hashlib.md5(data.encode(encoding='UTF-8')).hexdigest()


if __name__ == '__main__':
    kl = StringTools.getMd5('123456')
    print(kl)


# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(name="jgconfig",
      description="jgconfig",
      version="1.2.6",
      author="jiegemena",
      author_email="jiegemena@outlook.com",
      packages=find_packages(),
      install_requires=[    # 依赖列表
          'requests',
          'pymysql',
          'redis'
      ]
    )



import json
import os
import requests


ConfigJson={}


class ConfigServer:
    CONFIG={}

    @staticmethod
    def initConfig(filename='jgconfig.json'):
        if os.path.exists(filename) is False:
            with open(filename,'w+',encoding='utf-8') as fs:
                fs.write(json.dumps({"serverurl":"m1"}))
        with open(filename,'r',encoding='utf-8') as fs:
            confistr = fs.read()
        
        ConfigJson = json.loads(confistr)
        print('ConfigJson')
        print(ConfigJson)
        return ConfigJson

    @staticmethod
    def getNowVal(geturl:str,fapp:str,fkey:str):
        url = f'{geturl}/getval?fapp={fapp}&fkey={fkey}'
        b = requests.get(url)
        bjson = json.loads(b.text)
        if str(bjson['code']) == '200':
            return bjson['data']
        return False

    @staticmethod
    def Init(geturl=None):
        '''
            request = url

            {
                "code": "200",
                "msg": "ok",
                "data": [
                    {
                    "id": 1,
                    "fapp": "checkoneminute",
                    "fkey": "ison",
                    "fval": "1",
                    "fremark": "1：开，0：关闭"
                    },
                    {
                    "id": 2,
                    "fapp": "checkoneminute",
                    "fkey": "demo",
                    "fval": "1",
                    "fremark": "1：开，0：关闭"
                    }
                ]
            }
        '''
        if geturl is None:
            geturl = ConfigJson['serverurl']
        bak = requests.get(geturl)
        print(bak.text)
        jsonbak = json.loads(bak.text)
        if int(jsonbak['code']) != 200:
            raise Exception('配置服务器错误')

        for v in jsonbak['data']:
            ConfigServer.CONFIG[v['fkey']] = v['fval']

        return ConfigServer.CONFIG

    



